unquad.estimation.properties.configuration.DetectorConfig
=========================================================

.. currentmodule:: unquad.estimation.properties.configuration

.. autoclass:: DetectorConfig

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DetectorConfig.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DetectorConfig.adjustment
      ~DetectorConfig.aggregation
      ~DetectorConfig.alpha
      ~DetectorConfig.seed
      ~DetectorConfig.silent
   
   